==> dde-shell_0.0.40.tar.xz: BUILD/panels/osd/default/translations/org.deepin.ds.osd.default_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="54"/>
        <source>WLAN on</source>
        <translation>打开wifi</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="55"/>
        <source>WLAN off</source>
        <translation>关闭wifi</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="56"/>
        <source>Caps Lock on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="57"/>
        <source>Caps Lock off</source>
        <translation>小写</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="58"/>
        <source>Numeric keypad on</source>
        <translation>打开数字键盘</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="59"/>
        <source>Numeric keypad off</source>
        <translation>关闭数字键盘</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="60"/>
        <source>Touchpad on</source>
        <translation>打开触控板</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="61"/>
        <source>Touchpad off</source>
        <translation>关闭触控板</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="62"/>
        <source>Touchpad toggle</source>
        <translation>触摸板切换</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="63"/>
        <source>Fn toggle</source>
        <translation>Fn切换</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="64"/>
        <source>Airplane mode on</source>
        <translation>打开飞行模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="65"/>
        <source>Airplane mode off</source>
        <translation>关闭飞行模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="66"/>
        <source>Mute on</source>
        <translation>开启静音</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="67"/>
        <source>Mute off</source>
        <translation>关闭静音</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="68"/>
        <source>Balanced power</source>
        <translation>平衡模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="69"/>
        <source>Power saver</source>
        <translation>省电模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="70"/>
        <source>High performance</source>
        <translation>性能模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="71"/>
        <source>Window effect enabled</source>
        <translation>开启窗口特效</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="72"/>
        <source>Window effect disabled</source>
        <translation>关闭窗口特效</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="73"/>
        <source>Failed to enable window effects</source>
        <translation>打开窗口特效失败</translation>
    </message>
</context>
</TS>

==> dde-shell_1.0.10.tar.xz: BUILD/panels/osd/default/translations/org.deepin.ds.osd.default_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="54"/>
        <source>WLAN on</source>
        <translation>打开wifi</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="55"/>
        <source>WLAN off</source>
        <translation>关闭wifi</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="56"/>
        <source>Caps Lock on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="57"/>
        <source>Caps Lock off</source>
        <translation>小写</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="58"/>
        <source>Numeric keypad on</source>
        <translation>打开数字键盘</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="59"/>
        <source>Numeric keypad off</source>
        <translation>关闭数字键盘</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="60"/>
        <source>Touchpad on</source>
        <translation>打开触控板</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="61"/>
        <source>Touchpad off</source>
        <translation>关闭触控板</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="62"/>
        <source>Touchpad toggle</source>
        <translation>触摸板切换</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="63"/>
        <source>Fn toggle</source>
        <translation>Fn切换</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="64"/>
        <source>Airplane mode on</source>
        <translation>打开飞行模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="65"/>
        <source>Airplane mode off</source>
        <translation>关闭飞行模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="66"/>
        <source>Mute on</source>
        <translation>开启静音</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="67"/>
        <source>Mute off</source>
        <translation>关闭静音</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="68"/>
        <source>Balanced power</source>
        <translation>平衡模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="69"/>
        <source>Power saver</source>
        <translation>省电模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="70"/>
        <source>High performance</source>
        <translation>性能模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="71"/>
        <source>Window effect enabled</source>
        <translation>开启窗口特效</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="72"/>
        <source>Window effect disabled</source>
        <translation>关闭窗口特效</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="73"/>
        <source>Failed to enable window effects</source>
        <translation>打开窗口特效失败</translation>
    </message>
</context>
</TS>
